@@ -203,4 +203,27 @@ def GetPipelineArguments(mlproject_file_path, run_type, parameters):
             else:
                 pipelineParam = PipelineParameter(name=param, default_value=documents['entry_points'][run_type]['parameters'][param]['default'])
             arguments.append(pipelineParam)
-        return arguments
\ No newline at end of file
+        return arguments
+
+def GetOperationNameByVerb(operationVerb):
+    
+    luna_config = Init()
+    with open(luna_config['MLproject']) as file:
+        documents = yaml.full_load(file)
+        for operation in documents['entry_points']:
+            if documents['entry_points'][operation]['verb'] == operationVerb:
+                return operation
+
+    return None
+
+
+def GetOperationNameByNoun(operationNoun):
+    
+    luna_config = Init()
+    with open(luna_config['MLproject']) as file:
+        documents = yaml.full_load(file)
+        for operation in documents['entry_points']:
+            if documents['entry_points'][operation]['noun'] == operationVerb:
+                return operation
+
+    return None
\ No newline at end of file
